import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import ru.dima.weather.provider.WeatherProvider;
import ru.dima.weather.provider.WeatherProviderRegistry;

import java.util.List;

import static org.junit.jupiter.api.Assertions.*;
import static org.mockito.Mockito.mock;

public class WeatherProviderRegistryTest {
    private WeatherProviderRegistry registry;

    @BeforeEach
    public void setUp() {
        registry = new WeatherProviderRegistry();
    }

    @Test
    public void testRegisterAndGetWeatherProvider() {
        WeatherProvider provider = mock(WeatherProvider.class);
        registry.registerWeatherProvider(provider);

        List<WeatherProvider> providers = registry.getAllWeatherProviders();
        assertEquals(1, providers.size());
        assertSame(provider, providers.get(0));
    }

    @Test
    public void testGetAllWeatherProviders_Empty() {
        assertTrue(registry.getAllWeatherProviders().isEmpty());
    }

    @Test
    public void testGetAllWeatherProviders_Unmodifiable() {
        List<WeatherProvider> providers = registry.getAllWeatherProviders();
        assertThrows(UnsupportedOperationException.class, () -> providers.add(mock(WeatherProvider.class)));
    }
}
