package ru.dima.weather.city;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.mockito.Mockito;
import ru.dima.weather.cli.CLIInputReader;
import ru.dima.weather.cli.WeatherProviderCLISelector;
import ru.dima.weather.provider.WeatherProvider;
import ru.dima.weather.provider.WeatherProviderRegistry;

import java.util.Arrays;
import static org.junit.jupiter.api.Assertions.*;
import static org.mockito.Mockito.*;

public class WeatherProviderCLISelectorTest {
    private CLIInputReader cliInputReader;
    private WeatherProviderRegistry weatherProviderRegistry;
    private WeatherProviderCLISelector selector;

    @BeforeEach
    public void setUp() {
        cliInputReader = mock(CLIInputReader.class);
        weatherProviderRegistry = mock(WeatherProviderRegistry.class);
        selector = new WeatherProviderCLISelector(cliInputReader, weatherProviderRegistry);
    }

    @Test
    public void testSelectWeatherProvider_ValidInput() {
        WeatherProvider provider = mock(WeatherProvider.class);
        when(provider.getName()).thenReturn("Provider 1");
        when(weatherProviderRegistry.getAllWeatherProviders()).thenReturn(Arrays.asList(provider));
        when(cliInputReader.readInteger()).thenReturn(1);

        assertEquals(provider, selector.selectWeatherProviderFromCLI());
    }

    @Test
    public void testSelectWeatherProvider_InvalidInput() {
        WeatherProvider provider = mock(WeatherProvider.class);
        when(provider.getName()).thenReturn("Provider 1");
        when(weatherProviderRegistry.getAllWeatherProviders()).thenReturn(Arrays.asList(provider));
        when(cliInputReader.readInteger()).thenReturn(2).thenReturn(1);

        assertEquals(provider, selector.selectWeatherProviderFromCLI());
    }

    @Test
    public void testSelectWeatherProvider_EmptyProviderList() {
        when(weatherProviderRegistry.getAllWeatherProviders()).thenReturn(Arrays.asList());
        assertThrows(IndexOutOfBoundsException.class, () -> selector.selectWeatherProviderFromCLI());
    }
}
